FlutterMapGeojsonPlugin class

EvalPlugin for flutter_map_geojson2

Constructors

FlutterMapGeojsonPlugin()

Properties

hashCode int
The hash code for this object.
no setterinherited
identifier String
Unique identifier for this plugin. In most cases this should be the package name.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

configureForCompile(BridgeDeclarationRegistry registry) → void
Configure this plugin for use in a dart_eval Compiler or BridgeSerializer.
configureForRuntime(Runtime runtime) → void
Configure this plugin for use in a dart_eval Runtime.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited