$GeoJsonLayer class

dart_eval wrapper binding for GeoJsonLayer

Constructors

$GeoJsonLayer.wrap(GeoJsonLayer $value)
Wrap a GeoJsonLayer in a $GeoJsonLayer

Properties

$reified → GeoJsonLayer
Fully reify the underlying value so it can be used in a Dart context. For example, recursively transform collections into their underlying $values.
no setter
$value → GeoJsonLayer
The backing Dart value of this $Value.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

$getProperty(Runtime runtime, String identifier) → $Value?
Get a property by identifier on this instance
$getRuntimeType(Runtime runtime) int
Index of the class Type in the runtime dictionary. By definition can change from run to run, so it's customary to use Runtime.lookupType in implementations.
$setProperty(Runtime runtime, String identifier, $Value value) → void
Set a property by identifier on this instance to value
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

$file(Runtime runtime, $Value? thisValue, List<$Value?> args) → $Value?
Wrapper for the GeoJsonLayer.file constructor
$memory(Runtime runtime, $Value? thisValue, List<$Value?> args) → $Value?
Wrapper for the GeoJsonLayer.memory constructor
$network(Runtime runtime, $Value? thisValue, List<$Value?> args) → $Value?
Wrapper for the GeoJsonLayer.network constructor
$new(Runtime runtime, $Value? thisValue, List<$Value?> args) → $Value?
Wrapper for the GeoJsonLayer.new constructor
configureForRuntime(Runtime runtime) → void
Configure this class for use in a Runtime

Constants

$declaration → const BridgeClassDef
Compile-time class declaration of $GeoJsonLayer
$spec → const BridgeTypeSpec
Compile-time type specification of $GeoJsonLayer
$type → const BridgeTypeRef
Compile-time type declaration of $GeoJsonLayer