$InteractiveFlag class

dart_eval wrapper binding for InteractiveFlag

Constructors

$InteractiveFlag.wrap(InteractiveFlag $value)
Wrap a InteractiveFlag in a $InteractiveFlag

Properties

$reified → InteractiveFlag
Fully reify the underlying value so it can be used in a Dart context. For example, recursively transform collections into their underlying $values.
no setter
$value → InteractiveFlag
The backing Dart value of this $Value.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

$getProperty(Runtime runtime, String identifier) → $Value?
Get a property by identifier on this instance
$getRuntimeType(Runtime runtime) int
Index of the class Type in the runtime dictionary. By definition can change from run to run, so it's customary to use Runtime.lookupType in implementations.
$setProperty(Runtime runtime, String identifier, $Value value) → void
Set a property by identifier on this instance to value
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

$all(Runtime runtime, $Value? target, List<$Value?> args) → $Value?
Wrapper for the InteractiveFlag.all getter
$doubleTapDragZoom(Runtime runtime, $Value? target, List<$Value?> args) → $Value?
Wrapper for the InteractiveFlag.doubleTapDragZoom getter
$doubleTapZoom(Runtime runtime, $Value? target, List<$Value?> args) → $Value?
Wrapper for the InteractiveFlag.doubleTapZoom getter
$drag(Runtime runtime, $Value? target, List<$Value?> args) → $Value?
Wrapper for the InteractiveFlag.drag getter
$flingAnimation(Runtime runtime, $Value? target, List<$Value?> args) → $Value?
Wrapper for the InteractiveFlag.flingAnimation getter
$hasDoubleTapDragZoom(Runtime runtime, $Value? target, List<$Value?> args) → $Value?
Wrapper for the InteractiveFlag.hasDoubleTapDragZoom method
$hasDoubleTapZoom(Runtime runtime, $Value? target, List<$Value?> args) → $Value?
Wrapper for the InteractiveFlag.hasDoubleTapZoom method
$hasDrag(Runtime runtime, $Value? target, List<$Value?> args) → $Value?
Wrapper for the InteractiveFlag.hasDrag method
$hasFlag(Runtime runtime, $Value? target, List<$Value?> args) → $Value?
Wrapper for the InteractiveFlag.hasFlag method
$hasFlingAnimation(Runtime runtime, $Value? target, List<$Value?> args) → $Value?
Wrapper for the InteractiveFlag.hasFlingAnimation method
$hasMultiFinger(Runtime runtime, $Value? target, List<$Value?> args) → $Value?
Wrapper for the InteractiveFlag.hasMultiFinger method
$hasPinchMove(Runtime runtime, $Value? target, List<$Value?> args) → $Value?
Wrapper for the InteractiveFlag.hasPinchMove method
$hasPinchZoom(Runtime runtime, $Value? target, List<$Value?> args) → $Value?
Wrapper for the InteractiveFlag.hasPinchZoom method
$hasRotate(Runtime runtime, $Value? target, List<$Value?> args) → $Value?
Wrapper for the InteractiveFlag.hasRotate method
$hasScrollWheelZoom(Runtime runtime, $Value? target, List<$Value?> args) → $Value?
Wrapper for the InteractiveFlag.hasScrollWheelZoom method
$none(Runtime runtime, $Value? target, List<$Value?> args) → $Value?
Wrapper for the InteractiveFlag.none getter
$pinchMove(Runtime runtime, $Value? target, List<$Value?> args) → $Value?
Wrapper for the InteractiveFlag.pinchMove getter
$pinchZoom(Runtime runtime, $Value? target, List<$Value?> args) → $Value?
Wrapper for the InteractiveFlag.pinchZoom getter
$rotate(Runtime runtime, $Value? target, List<$Value?> args) → $Value?
Wrapper for the InteractiveFlag.rotate getter
$scrollWheelZoom(Runtime runtime, $Value? target, List<$Value?> args) → $Value?
Wrapper for the InteractiveFlag.scrollWheelZoom getter
configureForRuntime(Runtime runtime) → void
Configure this class for use in a Runtime

Constants

$declaration → const BridgeClassDef
Compile-time class declaration of $InteractiveFlag
$spec → const BridgeTypeSpec
Compile-time type specification of $InteractiveFlag
$type → const BridgeTypeRef
Compile-time type declaration of $InteractiveFlag