$CameraConstraint class

dart_eval wrapper binding for CameraConstraint

Constructors

$CameraConstraint.wrap(CameraConstraint $value)
Wrap a CameraConstraint in a $CameraConstraint

Properties

$reified → CameraConstraint
Fully reify the underlying value so it can be used in a Dart context. For example, recursively transform collections into their underlying $values.
no setter
$value → CameraConstraint
The backing Dart value of this $Value.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

$getProperty(Runtime runtime, String identifier) → $Value?
Get a property by identifier on this instance
$getRuntimeType(Runtime runtime) int
Index of the class Type in the runtime dictionary. By definition can change from run to run, so it's customary to use Runtime.lookupType in implementations.
$setProperty(Runtime runtime, String identifier, $Value value) → void
Set a property by identifier on this instance to value
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

$contain(Runtime runtime, $Value? thisValue, List<$Value?> args) → $Value?
Wrapper for the CameraConstraint.contain constructor
$containCenter(Runtime runtime, $Value? thisValue, List<$Value?> args) → $Value?
Wrapper for the CameraConstraint.containCenter constructor
$containLatitude(Runtime runtime, $Value? thisValue, List<$Value?> args) → $Value?
Wrapper for the CameraConstraint.containLatitude constructor
$unconstrained(Runtime runtime, $Value? thisValue, List<$Value?> args) → $Value?
Wrapper for the CameraConstraint.unconstrained constructor
configureForRuntime(Runtime runtime) → void
Configure this class for use in a Runtime

Constants

$declaration → const BridgeClassDef
Compile-time class declaration of $CameraConstraint
$spec → const BridgeTypeSpec
Compile-time type specification of $CameraConstraint
$type → const BridgeTypeRef
Compile-time type declaration of $CameraConstraint