$LatLng class

dart_eval wrapper binding for LatLng

Constructors

$LatLng.wrap(LatLng $value)
Wrap a LatLng in a $LatLng

Properties

$reified → LatLng
Fully reify the underlying value so it can be used in a Dart context. For example, recursively transform collections into their underlying $values.
no setter
$value → LatLng
The backing Dart value of this $Value.
final
hashCode int
The hash code for this object.
no setterinherited
latitude double
no setteroverride
latitudeInRad double
no setteroverride
longitude double
no setteroverride
longitudeInRad double
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

$getProperty(Runtime runtime, String identifier) → $Value?
Get a property by identifier on this instance
$getRuntimeType(Runtime runtime) int
Index of the class Type in the runtime dictionary. By definition can change from run to run, so it's customary to use Runtime.lookupType in implementations.
$setProperty(Runtime runtime, String identifier, $Value value) → void
Set a property by identifier on this instance to value
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
round({int decimals = 6}) → LatLng
override
toJson() Map<String, dynamic>
override
toSexagesimal() String
Converts lat/long values into sexagesimal
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

$fromJson(Runtime runtime, $Value? thisValue, List<$Value?> args) → $Value?
Wrapper for the LatLng.fromJson constructor
$fromSexagesimal(Runtime runtime, $Value? thisValue, List<$Value?> args) → $Value?
Wrapper for the LatLng.fromSexagesimal constructor
$new(Runtime runtime, $Value? thisValue, List<$Value?> args) → $Value?
Wrapper for the LatLng.new constructor
configureForRuntime(Runtime runtime) → void
Configure this class for use in a Runtime

Constants

$declaration → const BridgeClassDef
Compile-time class declaration of $LatLng
$spec → const BridgeTypeSpec
Compile-time type specification of $LatLng
$type → const BridgeTypeRef
Compile-time type declaration of $LatLng