$DistanceCalculator$bridge class

dart_eval bridge binding for DistanceCalculator

Inheritance
  • Object
  • DistanceCalculator
  • $DistanceCalculator$bridge

Constructors

$DistanceCalculator$bridge()
Forwarded constructor for DistanceCalculator.new

Properties

$reified → DistanceCalculator
Fully reify the underlying value so it can be used in a Dart context. For example, recursively transform collections into their underlying $values.
no setterinherited
$runtime → Runtime
no setterinherited
$value → $Bridge
The backing Dart value of this $Value.
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

$_get(String prop) → dynamic
inherited
$_invoke(String method, List<$Value?> args) → dynamic
inherited
$_set(String prop, $Value value) → void
inherited
$bridgeGet(String identifier) → $Value?
$bridgeSet(String identifier, $Value value) → void
$getProperty(Runtime runtime, String identifier) → $Value?
Get a property by identifier on this instance
inherited
$getRuntimeType(Runtime runtime) int
Index of the class Type in the runtime dictionary. By definition can change from run to run, so it's customary to use Runtime.lookupType in implementations.
inherited
$setProperty(Runtime runtime, String identifier, $Value value) → void
Set a property by identifier on this instance to value
inherited
distance(LatLng p1, LatLng p2) double
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
offset(LatLng from, double distanceInMeter, double bearing) → LatLng
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

configureForRuntime(Runtime runtime) → void
Configure this class for use in a Runtime

Constants

$declaration → const BridgeClassDef
Compile-time class declaration of $DistanceCalculator
$spec → const BridgeTypeSpec
Compile-time type specification of $DistanceCalculator$bridge
$type → const BridgeTypeRef
Compile-time type declaration of $DistanceCalculator$bridge