$ConflictAlgorithm class

dart_eval enum wrapper binding for ConflictAlgorithm

Constructors

$ConflictAlgorithm.wrap(ConflictAlgorithm $value)
Wrap a ConflictAlgorithm in a $ConflictAlgorithm

Properties

$reified → ConflictAlgorithm
Fully reify the underlying value so it can be used in a Dart context. For example, recursively transform collections into their underlying $values.
no setter
$value → ConflictAlgorithm
The backing Dart value of this $Value.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

$getProperty(Runtime runtime, String identifier) → $Value?
Get a property by identifier on this instance
$getRuntimeType(Runtime runtime) int
Index of the class Type in the runtime dictionary. By definition can change from run to run, so it's customary to use Runtime.lookupType in implementations.
$setProperty(Runtime runtime, String identifier, $Value value) → void
Set a property by identifier on this instance to value
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

$values(Runtime runtime, $Value? target, List<$Value?> args) → $Value?
Wrapper for the ConflictAlgorithm.values getter
configureForRuntime(Runtime runtime) → void
Configure this enum for use in a Runtime

Constants

$declaration → const BridgeEnumDef
Compile-time class declaration of $ConflictAlgorithm
$spec → const BridgeTypeSpec
Compile-time type specification of $ConflictAlgorithm
$type → const BridgeTypeRef
Compile-time type declaration of $ConflictAlgorithm