$InteractiveFlag class
dart_eval wrapper binding for InteractiveFlag
Constructors
- $InteractiveFlag.wrap(InteractiveFlag $value)
-
Wrap a
InteractiveFlagin a $InteractiveFlag
Properties
- $reified → InteractiveFlag
-
Fully reify the underlying value so it can be used in a Dart context.
For example, recursively transform collections into their underlying
$values.
no setter
- $value → InteractiveFlag
-
The backing Dart value of this
$Value.final - hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
$getProperty(
Runtime runtime, String identifier) → $Value? -
Get a property by
identifieron this instance -
$getRuntimeType(
Runtime runtime) → int -
Index of the class Type in the runtime dictionary. By definition
can change from run to run, so it's customary to use
Runtime.lookupTypein implementations. -
$setProperty(
Runtime runtime, String identifier, $Value value) → void -
Set a property by
identifieron this instance tovalue -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
$all(
Runtime runtime, $Value? target, List< $Value?> args) → $Value? -
Wrapper for the
InteractiveFlag.allgetter -
$doubleTapDragZoom(
Runtime runtime, $Value? target, List< $Value?> args) → $Value? -
Wrapper for the
InteractiveFlag.doubleTapDragZoomgetter -
$doubleTapZoom(
Runtime runtime, $Value? target, List< $Value?> args) → $Value? -
Wrapper for the
InteractiveFlag.doubleTapZoomgetter -
$drag(
Runtime runtime, $Value? target, List< $Value?> args) → $Value? -
Wrapper for the
InteractiveFlag.draggetter -
$flingAnimation(
Runtime runtime, $Value? target, List< $Value?> args) → $Value? -
Wrapper for the
InteractiveFlag.flingAnimationgetter -
$hasDoubleTapDragZoom(
Runtime runtime, $Value? target, List< $Value?> args) → $Value? -
Wrapper for the
InteractiveFlag.hasDoubleTapDragZoommethod -
$hasDoubleTapZoom(
Runtime runtime, $Value? target, List< $Value?> args) → $Value? -
Wrapper for the
InteractiveFlag.hasDoubleTapZoommethod -
$hasDrag(
Runtime runtime, $Value? target, List< $Value?> args) → $Value? -
Wrapper for the
InteractiveFlag.hasDragmethod -
$hasFlag(
Runtime runtime, $Value? target, List< $Value?> args) → $Value? -
Wrapper for the
InteractiveFlag.hasFlagmethod -
$hasFlingAnimation(
Runtime runtime, $Value? target, List< $Value?> args) → $Value? -
Wrapper for the
InteractiveFlag.hasFlingAnimationmethod -
$hasMultiFinger(
Runtime runtime, $Value? target, List< $Value?> args) → $Value? -
Wrapper for the
InteractiveFlag.hasMultiFingermethod -
$hasPinchMove(
Runtime runtime, $Value? target, List< $Value?> args) → $Value? -
Wrapper for the
InteractiveFlag.hasPinchMovemethod -
$hasPinchZoom(
Runtime runtime, $Value? target, List< $Value?> args) → $Value? -
Wrapper for the
InteractiveFlag.hasPinchZoommethod -
$hasRotate(
Runtime runtime, $Value? target, List< $Value?> args) → $Value? -
Wrapper for the
InteractiveFlag.hasRotatemethod -
$hasScrollWheelZoom(
Runtime runtime, $Value? target, List< $Value?> args) → $Value? -
Wrapper for the
InteractiveFlag.hasScrollWheelZoommethod -
$none(
Runtime runtime, $Value? target, List< $Value?> args) → $Value? -
Wrapper for the
InteractiveFlag.nonegetter -
$pinchMove(
Runtime runtime, $Value? target, List< $Value?> args) → $Value? -
Wrapper for the
InteractiveFlag.pinchMovegetter -
$pinchZoom(
Runtime runtime, $Value? target, List< $Value?> args) → $Value? -
Wrapper for the
InteractiveFlag.pinchZoomgetter -
$rotate(
Runtime runtime, $Value? target, List< $Value?> args) → $Value? -
Wrapper for the
InteractiveFlag.rotategetter -
$scrollWheelZoom(
Runtime runtime, $Value? target, List< $Value?> args) → $Value? -
Wrapper for the
InteractiveFlag.scrollWheelZoomgetter -
configureForRuntime(
Runtime runtime) → void -
Configure this class for use in a
Runtime
Constants
- $declaration → const BridgeClassDef
- Compile-time class declaration of $InteractiveFlag
- $spec → const BridgeTypeSpec
- Compile-time type specification of $InteractiveFlag
- $type → const BridgeTypeRef
- Compile-time type declaration of $InteractiveFlag